// ---rgf, 2006-01-19: utility class to allow defining file filters by file extension
//                     should allow Lee Pedin to exploit the FileDialog and JFileChooser

import java.io.File;
import java.io.FilenameFilter;

import java.util.Enumeration;
import java.util.Vector;

import javax.swing.filechooser.FileFilter;


// make sure that this class can be used for java.awt.FileDialog (FileNameFilter), and javax.swing.JFrame (FileFilter)
class RgfFilter extends FileFilter implements FilenameFilter
{
    private Vector vecExtensions=new Vector();  // Vector of file extensions
    private boolean bIgnoreCase=true;           // default to case insensitiveness
    private String  description=null;

    public RgfFilter (String d)                 // constructor allowing reception of the descriptive String
    {
        this.description=d;
    }

    public String getDescription()              // allow access to description
    {
        return this.description;
    }

    public void setDescription(String descr)    // allow to set a description
    {
        this.description=descr;
    }

    public boolean accept(File f)               // FileFilter for javax.swing.JFrame
    {
        if (f.isDirectory()==true)              // include directories in any case
        {
            return true;
        }
        return accept(f.getName());             // do the check
    }


    public boolean accept(File dir, String fname)   // FileNameFilter for java.awt.FileDialog
    {
        return accept(fname);
    }

    // this really does the work to determine whether the file should be included or not
    private boolean accept(String fname)        // test whether extension is accepted
    {
        String ufname=null;

        if (bIgnoreCase==true) ufname=fname.toUpperCase();  // get uppercase version of filename
        Enumeration e = this.vecExtensions.elements();  // get all elements

        while (e.hasMoreElements()==true)
        {
            String ext=(String) e.nextElement();

            if (fname.endsWith(ext)==true) return true;             // ends with file type
            if (bIgnoreCase==true)                                  // ends with file type
            {
                if (ufname.endsWith(ext.toUpperCase())==true) return true;
            }
        }
        return false;
    }


    public void addExtension(String extension)  // allow to add an extension
    {
        this.vecExtensions.add(extension);
    }

    public void setIgnoreCase(boolean bool)     // allow to set whether case should be ignored or not
    {
        this.bIgnoreCase=bool;
    }

    public boolean isIgnoreCase()               // returns whether case is ignored or not
    {
        return this.bIgnoreCase;
    }
}


